summaryrefslogtreecommitdiffstats
path: root/kioslave/sftp/process.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kioslave/sftp/process.cpp')
-rw-r--r--kioslave/sftp/process.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslave/sftp/process.cpp b/kioslave/sftp/process.cpp
index 6ef02108e..ca99b36bb 100644
--- a/kioslave/sftp/process.cpp
+++ b/kioslave/sftp/process.cpp
@@ -4,7 +4,7 @@
* This file is part of the KDE project, module kdesu.
* Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
*
* This file tqcontains code from TEShell.C of the KDE konsole.
* Copyright (c) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
*
* This is free software; you can use this library under the GNU Library
@@ -260,7 +260,7 @@ int MyPtyProcess::exec(TQCString command, QCStringList args)
// From now on, terminal output goes through the tty.
TQCString path;
- if (command.tqcontains('/'))
+ if (command.contains('/'))
path = command;
else
{
@@ -4,7 +4,7 @@
* Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
*
- * This file tqcontains code from TEShell.C of the KDE konsole.
+ * This file contains code from TEShell.C of the KDE konsole.
* Copyright (c) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
*